==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/container_cluster/ContainerClusterMonitoringConfig.java <==
package com.hashicorp.cdktf.providers.google.container_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:40.252Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.containerCluster.ContainerClusterMonitoringConfig")
@software.amazon.jsii.Jsii.Proxy(ContainerClusterMonitoringConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ContainerClusterMonitoringConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * advanced_datapath_observability_config block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#advanced_datapath_observability_config ContainerCluster#advanced_datapath_observability_config}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAdvancedDatapathObservabilityConfig() {
        return null;
    }

    /**
     * GKE components exposing metrics. Valid values include SYSTEM_COMPONENTS, APISERVER, SCHEDULER, CONTROLLER_MANAGER, STORAGE, HPA, POD, DAEMONSET, DEPLOYMENT and STATEFULSET.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#enable_components ContainerCluster#enable_components}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getEnableComponents() {
        return null;
    }

    /**
     * managed_prometheus block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#managed_prometheus ContainerCluster#managed_prometheus}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus getManagedPrometheus() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ContainerClusterMonitoringConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ContainerClusterMonitoringConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ContainerClusterMonitoringConfig> {
        java.lang.Object advancedDatapathObservabilityConfig;
        java.util.List<java.lang.String> enableComponents;
        com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus managedPrometheus;

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfig#getAdvancedDatapathObservabilityConfig}
         * @param advancedDatapathObservabilityConfig advanced_datapath_observability_config block.
         *                                            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#advanced_datapath_observability_config ContainerCluster#advanced_datapath_observability_config}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder advancedDatapathObservabilityConfig(com.hashicorp.cdktf.IResolvable advancedDatapathObservabilityConfig) {
            this.advancedDatapathObservabilityConfig = advancedDatapathObservabilityConfig;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfig#getAdvancedDatapathObservabilityConfig}
         * @param advancedDatapathObservabilityConfig advanced_datapath_observability_config block.
         *                                            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#advanced_datapath_observability_config ContainerCluster#advanced_datapath_observability_config}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder advancedDatapathObservabilityConfig(java.util.List<? extends com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig> advancedDatapathObservabilityConfig) {
            this.advancedDatapathObservabilityConfig = advancedDatapathObservabilityConfig;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfig#getEnableComponents}
         * @param enableComponents GKE components exposing metrics. Valid values include SYSTEM_COMPONENTS, APISERVER, SCHEDULER, CONTROLLER_MANAGER, STORAGE, HPA, POD, DAEMONSET, DEPLOYMENT and STATEFULSET.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#enable_components ContainerCluster#enable_components}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enableComponents(java.util.List<java.lang.String> enableComponents) {
            this.enableComponents = enableComponents;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfig#getManagedPrometheus}
         * @param managedPrometheus managed_prometheus block.
         *                          Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#managed_prometheus ContainerCluster#managed_prometheus}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder managedPrometheus(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus managedPrometheus) {
            this.managedPrometheus = managedPrometheus;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ContainerClusterMonitoringConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ContainerClusterMonitoringConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ContainerClusterMonitoringConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ContainerClusterMonitoringConfig {
        private final java.lang.Object advancedDatapathObservabilityConfig;
        private final java.util.List<java.lang.String> enableComponents;
        private final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus managedPrometheus;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.advancedDatapathObservabilityConfig = software.amazon.jsii.Kernel.get(this, "advancedDatapathObservabilityConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.enableComponents = software.amazon.jsii.Kernel.get(this, "enableComponents", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.managedPrometheus = software.amazon.jsii.Kernel.get(this, "managedPrometheus", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.advancedDatapathObservabilityConfig = builder.advancedDatapathObservabilityConfig;
            this.enableComponents = builder.enableComponents;
            this.managedPrometheus = builder.managedPrometheus;
        }

        @Override
        public final java.lang.Object getAdvancedDatapathObservabilityConfig() {
            return this.advancedDatapathObservabilityConfig;
        }

        @Override
        public final java.util.List<java.lang.String> getEnableComponents() {
            return this.enableComponents;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus getManagedPrometheus() {
            return this.managedPrometheus;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAdvancedDatapathObservabilityConfig() != null) {
                data.set("advancedDatapathObservabilityConfig", om.valueToTree(this.getAdvancedDatapathObservabilityConfig()));
            }
            if (this.getEnableComponents() != null) {
                data.set("enableComponents", om.valueToTree(this.getEnableComponents()));
            }
            if (this.getManagedPrometheus() != null) {
                data.set("managedPrometheus", om.valueToTree(this.getManagedPrometheus()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.containerCluster.ContainerClusterMonitoringConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ContainerClusterMonitoringConfig.Jsii$Proxy that = (ContainerClusterMonitoringConfig.Jsii$Proxy) o;

            if (this.advancedDatapathObservabilityConfig != null ? !this.advancedDatapathObservabilityConfig.equals(that.advancedDatapathObservabilityConfig) : that.advancedDatapathObservabilityConfig != null) return false;
            if (this.enableComponents != null ? !this.enableComponents.equals(that.enableComponents) : that.enableComponents != null) return false;
            return this.managedPrometheus != null ? this.managedPrometheus.equals(that.managedPrometheus) : that.managedPrometheus == null;
        }

        @Override
        public final int hashCode() {
            int result = this.advancedDatapathObservabilityConfig != null ? this.advancedDatapathObservabilityConfig.hashCode() : 0;
            result = 31 * result + (this.enableComponents != null ? this.enableComponents.hashCode() : 0);
            result = 31 * result + (this.managedPrometheus != null ? this.managedPrometheus.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/container_cluster/ContainerClusterMonitoringConfig.java <==
package com.hashicorp.cdktf.providers.google.container_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:14.188Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.containerCluster.ContainerClusterMonitoringConfig")
@software.amazon.jsii.Jsii.Proxy(ContainerClusterMonitoringConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ContainerClusterMonitoringConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * advanced_datapath_observability_config block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#advanced_datapath_observability_config ContainerCluster#advanced_datapath_observability_config}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig getAdvancedDatapathObservabilityConfig() {
        return null;
    }

    /**
     * GKE components exposing metrics. Valid values include SYSTEM_COMPONENTS, APISERVER, SCHEDULER, CONTROLLER_MANAGER, STORAGE, HPA, POD, DAEMONSET, DEPLOYMENT and STATEFULSET.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#enable_components ContainerCluster#enable_components}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getEnableComponents() {
        return null;
    }

    /**
     * managed_prometheus block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#managed_prometheus ContainerCluster#managed_prometheus}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus getManagedPrometheus() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ContainerClusterMonitoringConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ContainerClusterMonitoringConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ContainerClusterMonitoringConfig> {
        com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig advancedDatapathObservabilityConfig;
        java.util.List<java.lang.String> enableComponents;
        com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus managedPrometheus;

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfig#getAdvancedDatapathObservabilityConfig}
         * @param advancedDatapathObservabilityConfig advanced_datapath_observability_config block.
         *                                            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#advanced_datapath_observability_config ContainerCluster#advanced_datapath_observability_config}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder advancedDatapathObservabilityConfig(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig advancedDatapathObservabilityConfig) {
            this.advancedDatapathObservabilityConfig = advancedDatapathObservabilityConfig;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfig#getEnableComponents}
         * @param enableComponents GKE components exposing metrics. Valid values include SYSTEM_COMPONENTS, APISERVER, SCHEDULER, CONTROLLER_MANAGER, STORAGE, HPA, POD, DAEMONSET, DEPLOYMENT and STATEFULSET.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#enable_components ContainerCluster#enable_components}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enableComponents(java.util.List<java.lang.String> enableComponents) {
            this.enableComponents = enableComponents;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfig#getManagedPrometheus}
         * @param managedPrometheus managed_prometheus block.
         *                          Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#managed_prometheus ContainerCluster#managed_prometheus}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder managedPrometheus(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus managedPrometheus) {
            this.managedPrometheus = managedPrometheus;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ContainerClusterMonitoringConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ContainerClusterMonitoringConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ContainerClusterMonitoringConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ContainerClusterMonitoringConfig {
        private final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig advancedDatapathObservabilityConfig;
        private final java.util.List<java.lang.String> enableComponents;
        private final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus managedPrometheus;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.advancedDatapathObservabilityConfig = software.amazon.jsii.Kernel.get(this, "advancedDatapathObservabilityConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig.class));
            this.enableComponents = software.amazon.jsii.Kernel.get(this, "enableComponents", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.managedPrometheus = software.amazon.jsii.Kernel.get(this, "managedPrometheus", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.advancedDatapathObservabilityConfig = builder.advancedDatapathObservabilityConfig;
            this.enableComponents = builder.enableComponents;
            this.managedPrometheus = builder.managedPrometheus;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig getAdvancedDatapathObservabilityConfig() {
            return this.advancedDatapathObservabilityConfig;
        }

        @Override
        public final java.util.List<java.lang.String> getEnableComponents() {
            return this.enableComponents;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterMonitoringConfigManagedPrometheus getManagedPrometheus() {
            return this.managedPrometheus;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAdvancedDatapathObservabilityConfig() != null) {
                data.set("advancedDatapathObservabilityConfig", om.valueToTree(this.getAdvancedDatapathObservabilityConfig()));
            }
            if (this.getEnableComponents() != null) {
                data.set("enableComponents", om.valueToTree(this.getEnableComponents()));
            }
            if (this.getManagedPrometheus() != null) {
                data.set("managedPrometheus", om.valueToTree(this.getManagedPrometheus()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.containerCluster.ContainerClusterMonitoringConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ContainerClusterMonitoringConfig.Jsii$Proxy that = (ContainerClusterMonitoringConfig.Jsii$Proxy) o;

            if (this.advancedDatapathObservabilityConfig != null ? !this.advancedDatapathObservabilityConfig.equals(that.advancedDatapathObservabilityConfig) : that.advancedDatapathObservabilityConfig != null) return false;
            if (this.enableComponents != null ? !this.enableComponents.equals(that.enableComponents) : that.enableComponents != null) return false;
            return this.managedPrometheus != null ? this.managedPrometheus.equals(that.managedPrometheus) : that.managedPrometheus == null;
        }

        @Override
        public final int hashCode() {
            int result = this.advancedDatapathObservabilityConfig != null ? this.advancedDatapathObservabilityConfig.hashCode() : 0;
            result = 31 * result + (this.enableComponents != null ? this.enableComponents.hashCode() : 0);
            result = 31 * result + (this.managedPrometheus != null ? this.managedPrometheus.hashCode() : 0);
            return result;
        }
    }
}
